@@ -180,12 +180,8 @@ class Ui_MainWindow(object):
         self.lblGraphic.setObjectName("lblGraphic")
         self.btnSaveGraphic = QtWidgets.QCommandLinkButton(self.tab)
         self.btnSaveGraphic.setEnabled(False)
-        self.btnSaveGraphic.setGeometry(QtCore.QRect(700, 530, 48, 51))
-        self.btnSaveGraphic.setText("")
-        icon = QtGui.QIcon()
-        icon.addPixmap(QtGui.QPixmap("salvar.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
-        self.btnSaveGraphic.setIcon(icon)
-        self.btnSaveGraphic.setIconSize(QtCore.QSize(35, 35))
+        self.btnSaveGraphic.setGeometry(QtCore.QRect(680, 540, 60, 30))
+        self.btnSaveGraphic.setText("Save")
         self.btnSaveGraphic.setObjectName("btnSaveGraphic")
         self.tabWidget.addTab(self.tab, "")
         self.tab_2 = QtWidgets.QWidget()
@@ -206,10 +202,8 @@ class Ui_MainWindow(object):
         self.btnRunScript.setObjectName("btnRunScript")
         self.btnSaveScript = QtWidgets.QCommandLinkButton(self.tab_2)
         self.btnSaveScript.setEnabled(False)
-        self.btnSaveScript.setGeometry(QtCore.QRect(706, 540, 51, 51))
-        self.btnSaveScript.setText("")
-        self.btnSaveScript.setIcon(icon)
-        self.btnSaveScript.setIconSize(QtCore.QSize(35, 35))
+        self.btnSaveScript.setGeometry(QtCore.QRect(680, 540, 60, 30))
+        self.btnSaveScript.setText("Save")
         self.btnSaveScript.setObjectName("btnSaveScript")
         self.tabWidget.addTab(self.tab_2, "")
         self.checkSameG = QtWidgets.QCheckBox(self.centralwidget)
